<template>
  <div class="fixed-asset">
    <div class="asset-left">
      <div class="statistics">
        <img src="@/assets/img/publicTitle/title-股权.png" alt="">
        <div class="statistics-content">
          <div class="title">总账面价值(万元)</div>
          <div class="num">818.67</div>
        </div>
      </div>
      <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="各类公司统计" />
      <div class="left-content">
        <div class="item" v-for="(item, index) in statisticsList"
          :style="{ 'border-right': (index + 1) % 2 == 0 ? 'none' : '1px solid #E6F1FF' }">
          <div>
            <div class="amount">{{ item.value }}</div>
            <div class="label">{{ item.label }}</div>
          </div>
        </div>
      </div>
    </div>
    <div class="asset-right">
      <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="股权关系图谱">
        <el-select v-model="value" placeholder="请选择" size="mini" style="width: 160px;">
          <el-option v-for="item in options" :key="item.value" :label="item.label" :value="item.value">
          </el-option>
        </el-select>
      </PublicTitle>
      <div id="chartDom"></div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import PublicTitle from '@/components/PublicTitle/index'
import api from '@/api/InvestmentFinancingAssets/InvestmentFinancingEnter/EquityRelationshipMap.js'

export default {
  name: 'InvestmentFinancingAssets',
  components: {
    PublicTitle,
  },
  data() {
    return {
      dataList: [],
      nodeList: [],
      linkList: [],
      treeData: [],
      loading: false,
      queryParams: {
        orgId: null,
        orgName: null,
      },
      statisticsList: [
        {
          label: '二级控股子公司(家)',
          value: 10
        }, {
          label: '三级控股子公司',
          value: 10
        }, {
          label: '二级全资子公司(家)',
          value: 10
        }, {
          label: '三级全资子公司',
          value: 10
        }, {
          label: '二级参股子公司',
          value: 10
        }, {
          label: '三级参股子公司',
          value: 10
        }, {
          label: '有限合伙企业',
          value: 10
        },
      ],
      options: [],
      value: ''
    }
  },
  created() {
    this.loadData()

  },
  mounted() {
  },
  methods: {
    //获取数据
    loadData() {
      this.tableLoading = true
      this.nodeList = []
      this.linkList = []
      api.queryData(this.queryParams, (res) => {
        this.dataList = [res]
        this.linkList = this.linkProcessing(res)
        this.nodeList = this.nodeProcessing(res)
        this.tableLoading = false
        this.initChat()
      })
    },
    // node数据处理
    nodeProcessing(data) {
      const result = []
      function traverse(node, level) {
        const name = node.name
        const id = node.id
        result.push({ name, level, id })
        if (node.list && node.list.length > 0) {
          node.list.forEach((childNode) => {
            traverse(childNode, childNode.level)
          })
        }
      }
      traverse(data, data.level)
      return result
    },
    // link数据处理
    linkProcessing(data) {
      const result = []
      function traverse(node, parentId) {
        const id = node.id
        const type = node.type
        const equityRatio = node.equityRatio

        if (type === 2) {
          result.push({
            source: parentId,
            target: id,
            eq: `持股${equityRatio}%`,
          })
        } else if (type === 1) {
          result.push({
            source: id,
            target: parentId,
            eq: `持股${equityRatio}%`,
          })
        }

        if (node.list && node.list.length > 0) {
          node.list.forEach((childNode) => {
            traverse(childNode, id)
          })
        }
      }
      traverse(data, '')
      return result
    },
    initChat() {
      let chartDom = echarts.init(document.getElementById('chartDom'))
      const color1 = '#36DB99'
      const color2 = '#4AC3FF'

      this.nodeList.forEach((node) => {
        if (node.level === 1) {
          node.symbolSize = 140
          node.itemStyle = {
            color: color1,
          }
        } else if (node.level === 2) {
          node.symbolSize = 120
          node.itemStyle = {
            color: color2,
          }
        } else if (node.level === 3) {
          node.symbolSize = 100
          node.itemStyle = {
            color: color2,
          }
        }
      })
      this.linkList.forEach((link, index) => {
        // link.id = index

        link.label = {
          align: 'center',
          fontSize: 16,
          color: '#000',
          offset: [0, -5], // 微调文字位置，根据需要调整偏移量
        }
        link.lineStyle = {
          color: color2,
          curveness: 0.3,
        }
      })
      let option = {

        series: [
          {
            type: 'graph',
            layout: 'force',
            symbolSize: 80,
            draggable: true,
            roam: true,
            focusNodeAdjacency: true,
            edgeSymbol: ['', 'arrow'],
            edgeSymbolSize: [15, 15],
            edgeLabel: {
              normal: {
                show: true,
                textStyle: {
                  fontSize: 20,
                },
                formatter(x) {
                  return x.data.eq
                },
              },
            },
            label: {
              show: true,
              color: '#FFF',
              fontSize: 16,
              formatter: function (params) {
                console.log(params)
                var name = params.name
                // 将字符串按照每 10 个字符进行分割，并插入换行符
                var nameArr = []
                if (params.data.level === 1) {
                  nameArr = name.match(/.{1,7}/g)
                } else if (params.data.level === 2) {
                  nameArr = name.match(/.{1,7}/g)
                } else if (params.data.level === 3) {
                  nameArr = name.match(/.{1,6}/g)
                }
                return nameArr.join('\n')
              },
            },
            force: {
              repulsion: 2000,
              edgeLength: 120,
            },
            data: this.nodeList,
            links: this.linkList,
          },
        ],
      }
      chartDom.setOption(option)
      console.log(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
  }
}
</script>

<style lang="scss" scoped>
.fixed-asset {
  // box-sizing: border-box;
  // padding: 15px 0;
  width: 100%;
  height: 100%;
  padding: 16px 24px;
  box-sizing: border-box;
  display: flex;
  justify-content: space-between;
  align-items: center;

  .asset-left {
    width: 30%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #FFFFFF;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;

    .statistics {
      height: 152px;
      background: #198CFF;
      border-radius: 8px 8px 8px 8px;
      padding: 0 16px;
      box-sizing: border-box;
      margin-bottom: 40px;
      display: flex;
      align-items: center;

      img {
        width: 164px;
        height: 152px;
      }

      .statistics-content {
        height: 100%;
        padding: 24px 0;
        box-sizing: border-box;
        display: flex;
        flex-direction: column;
        justify-content: space-evenly;

        .title {
          font-size: 16px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          color: #FFFFFF;
          line-height: 21px;
        }

        .num {
          font-size: 26px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 700;
          color: #FFFFFF;
          line-height: 26px;
        }

        .line {
          width: 233px;
          height: 0px;
          opacity: 1;
          border: 1px solid #E6F1FF;
        }

        .totality {
          font-size: 14px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          color: #FFFFFF;
          line-height: 18px;

          span {
            font-size: 16px;
            font-family: Microsoft YaHei, Microsoft YaHei;
            font-weight: 700;
            color: #FFFFFF;
            line-height: 21px;
          }
        }
      }
    }

    .left-content {
      width: 100%;
      height: calc(100% - 242PX);
      border-radius: 8px 8px 8px 8px;
      opacity: 1;
      border: 1px solid #E6F1FF;
      margin-top: 16px;
      display: flex;
      flex-wrap: wrap;
      .item {
        width: 50%;
        height: 25%;

        // height: 100%;
        box-sizing: border-box;
        border-right: 1px solid #E6F1FF;
        border-bottom: 1px solid #E6F1FF;
        text-align: center;
        display: flex;
        flex-direction: column;
        justify-content: space-evenly;

        .amount {
          font-size: 26px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 700;
          color: #0F2A4D;
          line-height: 34px;
        }

        .label {
          font-size: 16px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          color: #7A8899;
          line-height: 21px;
        }
      }
    }
  }


  .asset-right {
    width: calc(70% - 16px);
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #FFFFFF;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;

    #chartDom {
      width: 100%;
      height: calc(100% - 30px);
    }

  }
}
</style>
